@@ -13,4 +13,6 @@ from .nekos_life import NekosLifeAPI
 from .nekobot import NekoBotAPI
 from .neko_love import NekoLoveAPI
 from .nekos_moe import NekosMoeAPI
-from .nekos_best import NekosBest
\ No newline at end of file
+from .nekos_best import NekosBest
+from .waifu_im import WaifuImAPI
+from .nekos_api import NekosAPI
