@@ -13,7 +13,7 @@ class ServerError(Exception):
         self, status_code: int, msg: typing.Optional[str] = None, *args, **kwargs
     ):
         super().__init__(
-            f"The server returned an error{': ' + msg if msg else ''}. (Status code: {status_code})",
+            f"The server returned an error{': ' + msg if msg else '.'} (Status code: {status_code})",
             *args,
             **kwargs,
         )
@@ -36,3 +36,12 @@ class Forbidden(Exception):
     """
     Error raised when the user is not authorized to perform the action.
     """
+
+
+class NotFound(ServerError):
+    """
+    Error raised when the item is not found.
+    """
+
+    def __init__(self, msg: typing.Optional[str] = "Not found", *args, **kwargs):
+        ServerError.__init__(self, 404, msg, *args, **kwargs)
